@@ -15,9 +15,11 @@ import re
 import sys
 import warnings
 import xml.etree.ElementTree as ET
+from typing import Union
 
 import h5py
 import numpy as np
+from numpy.typing import DTypeLike
 
 from mintpy.objects import (
     DSET_UNIT_DICT,
@@ -135,11 +137,11 @@ DATA_TYPE_GDAL2NUMPY = {
     11: 'complex128',
     12: 'uint64',
     13: 'int64',
+    14: 'int8',         # GDAL >= 3.7
 }
 
 DATA_TYPE_NUMPY2GDAL = {
     "uint8"     : 1,    # GDT_Byte
-    "int8"      : 1,    # GDT_Int8   (GDAL >= 3.7)
     "uint16"    : 2,    # GDT_UInt16
     "int16"     : 3,    # GDT_Int16
     "uint32"    : 4,    # GDT_UInt32
@@ -152,6 +154,7 @@ DATA_TYPE_NUMPY2GDAL = {
     "complex128": 11,   # GDT_CFloat64
     "uint64"    : 12,   # GDT_UInt64 (GDAL >= 3.5)
     "int64"     : 13,   # GDT_Int64  (GDAL >= 3.5)
+    "int8"      : 14,   # GDT_Int8   (GDAL >= 3.7)
 }
 
 # 3 - ISCE
@@ -204,7 +207,47 @@ SPECIAL_STR2NUM = {
 }
 
 
-###########################################################################
+#########################################################################
+def numpy_to_gdal_dtype(np_dtype: DTypeLike) -> int:
+    """Convert NumPy dtype to GDAL dtype.
+
+    Modified from dolphin.utils.numpy_to_gdal_type().
+
+    Parameters: np_dtype  - DTypeLike, NumPy dtype to convert.
+    Returns:    gdal_code - int, GDAL type code corresponding to `np_dtype`.
+    """
+    from osgeo import gdal_array, gdalconst
+    np_dtype = np.dtype(np_dtype)
+
+    # convert dtype using the GDAL function/attribute
+    if np.issubdtype(bool, np_dtype):
+        gdal_code = gdalconst.GDT_Byte
+    else:
+        gdal_code = gdal_array.NumericTypeCodeToGDALTypeCode(np_dtype)
+
+    # if provided dtype is not support GDAL, e.g. np.dtype('>i4')
+    if gdal_code is None:
+        raise TypeError(f"dtype {np_dtype} not supported by GDAL.")
+
+    return gdal_code
+
+
+def gdal_to_numpy_dtype(gdal_dtype: Union[str, int]) -> np.dtype:
+    """Convert GDAL dtype to NumPy dtype.
+
+    Modified from dolphin.utils.gdal_to_numpy_type().
+
+    Parameters: gdal_dtype - str/int, GDAL dtype to convert.
+    Returns:    np_dtype   - np.dtype, NumPy dtype
+    """
+    from osgeo import gdal, gdal_array
+    if isinstance(gdal_dtype, str):
+        gdal_dtype = gdal.GetDataTypeByName(gdal_dtype)
+    np_dtype = np.dtype(gdal_array.GDALTypeCodeToNumericTypeCode(gdal_dtype))
+    return np_dtype
+
+
+#########################################################################
 ## Slice-based data identification for data reading:
 ##
 ## slice   : np.ndarray in 2D,  with/without '-' in their names
@@ -252,7 +295,7 @@ SPECIAL_STR2NUM = {
 ##     recons-20150115
 ##     cmask
 ##
-###########################################################################
+#########################################################################
 
 
 
@@ -281,6 +324,7 @@ def read(fname, box=None, datasetName=None, print_msg=True, xstep=1, ystep=1, da
         data, atr = readfile.read('geometryRadar.h5', datasetName='bperp')
         data, atr = readfile.read('100120-110214.unw', box=(100,1100, 500, 2500))
     """
+    fname = os.fspath(fname)  # Convert from possible pathlib.Path
     # metadata
     dsname4atr = None   #used to determine UNIT
     if isinstance(datasetName, list):
@@ -963,13 +1007,14 @@ def read_attribute(fname, datasetName=None, metafile_ext=None):
                          ...
     Returns:    atr : dict, attributes dictionary
     """
+    fname = os.fspath(fname)  # Convert from possible pathlib.Path
     fdir = os.path.dirname(fname)
     fbase, fext = os.path.splitext(os.path.basename(fname))
     fext = fext.lower()
     if not os.path.isfile(fname):
-        msg = f'input file not existed: {fname}\n'
+        msg = f'input file does not exist: {fname}\n'
         msg += 'current directory: '+os.getcwd()
-        raise Exception(msg)
+        raise FileNotFoundError(msg)
 
     # HDF5 files
     if fext in ['.h5', '.he5']:
@@ -983,7 +1028,7 @@ def read_attribute(fname, datasetName=None, metafile_ext=None):
             d1_list = [i for i in f.keys() if isinstance(f[i], h5py.Dataset) and f[i].ndim >= 2]
 
         # FILE_TYPE
-        # pre-defined/known dataset/group names > existing FILE_TYPE > exsiting dataset/group names
+        # pre-defined/known dataset/group names > existing FILE_TYPE > existing dataset/group names
         py2_mintpy_stack_files = ['interferograms', 'coherence', 'wrapped'] #obsolete mintpy format
         if any(i in d1_list for i in ['unwrapPhase', 'rangeOffset', 'azimuthOffset']):
             ftype = 'ifgramStack'
@@ -1017,7 +1062,7 @@ def read_attribute(fname, datasetName=None, metafile_ext=None):
             atr = giantIfgramStack(fname).get_metadata()
 
         elif len(atr) > 0 and 'WIDTH' in atr.keys():
-            # use the attribute at root level, which is already read from the begining
+            # use the attribute at root level, which is already read from the beginning
 
             # grab attribute of dataset if specified, e.g. UNIT, no-data value, etc.
             if datasetName and datasetName in d1_list:
@@ -1153,7 +1198,7 @@ def read_attribute(fname, datasetName=None, metafile_ext=None):
             raise FileNotFoundError('No UAVSAR *.ann file found!')
 
     else:
-        # grab all existed potential metadata file given the data file in prefered order/priority
+        # grab all existed potential metadata file given the data file in preferred order/priority
         # .aux.xml file does not have geo-coordinates info
         # .vrt file (e.g. incLocal.rdr.vrt from isce) does not have band interleavee info
         metafiles = [
@@ -1357,7 +1402,7 @@ def read_template(fname, delimiter='=', skip_chars=None):
 
     Parameters: fname      - str, full path to the template file
                 delimiter  - str, string to separate the key and value
-                skip_chars - list of str, skip certain charaters in values
+                skip_chars - list of str, skip certain characters in values
     Returns:    template   - dict, file content
     Examples:   template = read_template('KyushuAlosAT424.txt')
                 template = read_template('smallbaselineApp.cfg')
@@ -1996,12 +2041,10 @@ def read_gdal(fname, box=None, band=1, cpx_band='phase', xstep=1, ystep=1):
         box = (0, 0, ds.RasterXSize, ds.RasterYSize)
 
     # read
-    # Note: do not use gdal python kwargs because of error: 'BandRasterIONumPy', argument 3 of type 'double'
-    # Recommendation: use rasterio instead of gdal pytho
-    # Link: https://gdal.org/python/osgeo.gdal.Band-class.html#ReadAsArray
-    #kwargs = dict(xoff=box[0], win_xsize=box[2]-box[0],
-    #              yoff=box[1], win_ysize=box[3]-box[1])
-    data = bnd.ReadAsArray()[box[1]:box[3], box[0]:box[2]]
+    # Link: https://gdal.org/api/python/osgeo.gdal.html#osgeo.gdal.Band.ReadAsArray
+    kwargs = dict(xoff=int(box[0]), win_xsize=int(box[2]-box[0]),
+                  yoff=int(box[1]), win_ysize=int(box[3]-box[1]))
+    data = bnd.ReadAsArray(**kwargs)
 
     # adjust output band for complex data
     data_type = DATA_TYPE_GDAL2NUMPY[bnd.DataType]
@@ -2192,7 +2235,7 @@ def read_complex_float32(fname, box=None, byte_order='l', band='phase'):
 
     ROI_PAC file: .slc, .int, .amp
 
-    Data is sotred as:
+    Data is stored as:
     real, imaginary, real, imaginary, ...
     real, imaginary, real, imaginary, ...
     ...
