@@ -164,6 +164,8 @@ def update_inps_with_file_metadata(inps, metadata):
     if not inps.outfile:
         # ignore whitespaces in the filename
         fbase = inps.fig_title.replace(' ', '')
+        if not inps.disp_whitespace:
+            fbase += '_nws'
         inps.outfile = [f'{fbase}{inps.fig_ext}']
 
     inps = update_figure_setting(inps)
@@ -331,24 +333,57 @@ def prep_slice(cmd, auto_fig=False):
                 atr  - dict, metadata
                 inps - namespace, input argument for plot setup
     Example:
+        from cartopy import crs as ccrs
         from mintpy.view import prep_slice, plot_slice
 
+        # initiate matplotlib figure/axes
         subplot_kw = dict(projection=ccrs.PlateCarree())
         fig, ax = plt.subplots(figsize=[4, 3], subplot_kw=subplot_kw)
-        W, N, E, S = (-91.670, -0.255, -91.370, -0.515)    # geo_box
 
+        # compose view.py command
         cmd = 'view.py geo_velocity.h5 velocity --mask geo_maskTempCoh.h5 --dem srtm1.dem --dem-nocontour '
-        cmd += f'--sub-lon {W} {E} --sub-lat {S} {N} -c jet -v -3 10 '
-        cmd += '--cbar-loc bottom --cbar-nbins 3 --cbar-ext both --cbar-size 5% '
+        cmd += f'--sub-lon -91.7 -91.4 --sub-lat -0.5 -0.3 -c jet -v -3 10 '
+        cmd += '--cbar-loc bottom --cbar-nbins 3 --cbar-ext both --cbar-label "LOS velocity [cm/year]" '
         cmd += '--lalo-step 0.2 --lalo-loc 1 0 1 0 --scalebar 0.3 0.80 0.05 --notitle'
 
+        # call prep/plot_slice()
         data, atr, inps = prep_slice(cmd)
         ax, inps, im, cbar = plot_slice(ax, data, atr, inps)
         plt.show()
     """
     # parse
     from mintpy.cli.view import cmd_line_parse
-    inps = cmd_line_parse(cmd.split()[1:])
+    iargs = cmd.split()[1:]
+
+    # support option inputs of a list of characters (separated by whitespaces but quoted)
+    # e.g.: --cbar-label "LOS velocity [cm/yar]" --title "S1 asc. velocity"
+    # to be consistent with the behavior in command line parsing
+    if any(x.startswith(('"', '\'')) for x in iargs):
+        # backup and reset
+        temp_iargs = list(iargs)
+        iargs = []
+
+        # get index of quoted list of characters
+        ind0s = np.where([x.startswith(('"', '\'')) for x in temp_iargs])[0]
+        ind1s = np.where([x.endswith(('"', '\'')) for x in temp_iargs])[0]
+        for i, temp_iarg in enumerate(temp_iargs):
+            if any(ind0 <= i <= ind1 for ind0, ind1 in zip(ind0s, ind1s)):
+                # quoted list of characters
+                for ind0, ind1 in zip(ind0s, ind1s):
+                    if i == ind0:
+                        temp = temp_iarg[1:]
+                    elif ind0 < i < ind1:
+                        temp += ' ' + temp_iarg
+                    elif i == ind1:
+                        temp += ' ' + temp_iarg[:-1]
+                        iargs.append(temp)
+                        break
+            else:
+                # regular unquoted list of characters
+                iargs.append(temp_iarg)
+
+    # run parse
+    inps = cmd_line_parse(iargs)
 
     global vprint
     vprint = print if inps.print_msg else lambda *args, **kwargs: None
@@ -436,15 +471,7 @@ def plot_slice(ax, data, metadata, inps):
                 inps     : Namespace for input options
                 im       : matplotlib.image.AxesImage object
                 cbar     : matplotlib.colorbar.Colorbar object
-    Example:
-        from matplotlib import pyplot as plt
-        from mintpy.utils import readfile
-        from mintpy.view import plot_slice
-
-        data, atr = readfile.read('velocity.h5')
-        fig, ax = plt.subplots()
-        ax = plot_slice(ax, data, atr)[0]
-        plt.show()
+    Example: See prep_slice() above for example usage.
     """
     global vprint
     vprint = print if inps.print_msg else lambda *args, **kwargs: None
@@ -477,7 +504,7 @@ def plot_slice(ax, data, metadata, inps):
         vprint('plot in geo-coordinate')
 
         # extent info for matplotlib.imshow and other functions
-        extent = (inps.geo_box[0], inps.geo_box[2], inps.geo_box[3], inps.geo_box[1])  # (W, E, S, N)
+        inps.extent = (inps.geo_box[0], inps.geo_box[2], inps.geo_box[3], inps.geo_box[1])  # (W, E, S, N)
         SNWE = (inps.geo_box[3], inps.geo_box[1], inps.geo_box[0], inps.geo_box[2])
 
         # Draw coastline using cartopy resolution parameters
@@ -496,9 +523,8 @@ def plot_slice(ax, data, metadata, inps):
                 print_msg=inps.print_msg,
             )
 
-        # Plot Data
+        # Reference (InSAR) data to a GNSS site
         coord = ut.coordinate(metadata)
-        vprint('plotting image ...')
         if inps.disp_gps and inps.gps_component and inps.ref_gps_site:
             ref_site_lalo = GPS(site=inps.ref_gps_site).get_stat_lat_lon(print_msg=False)
             y, x = coord.geo2radar(ref_site_lalo[0], ref_site_lalo[1])[0:2]
@@ -510,9 +536,14 @@ def plot_slice(ax, data, metadata, inps):
             # do not show the original InSAR reference point
             inps.disp_ref_pixel = False
 
-        im = ax.imshow(data, cmap=inps.colormap, vmin=inps.vlim[0], vmax=inps.vlim[1],
-                       extent=extent, origin='upper', interpolation=inps.interpolation,
-                       alpha=inps.transparency, animated=inps.animation, zorder=1)
+        # Plot data
+        if inps.disp_dem_blend:
+            im = pp.plot_blend_image(ax, data, dem, inps, print_msg=inps.print_msg)
+        else:
+            vprint('plotting data ...')
+            im = ax.imshow(data, cmap=inps.colormap, vmin=inps.vlim[0], vmax=inps.vlim[1],
+                           extent=inps.extent, origin='upper', interpolation=inps.interpolation,
+                           alpha=inps.transparency, animated=inps.animation, zorder=1)
 
         # Draw faultline using GMT lonlat file
         if inps.faultline_file:
@@ -539,6 +570,7 @@ def plot_slice(ax, data, metadata, inps):
                 loc=inps.scalebar,
                 labelpad=inps.scalebar_pad,
                 font_size=inps.font_size,
+                linewidth=inps.scalebar_linewidth,
             )
 
         # Lat Lon labels
@@ -572,8 +604,6 @@ def plot_slice(ax, data, metadata, inps):
 
         # Show UNR GPS stations
         if inps.disp_gps:
-            SNWE = (inps.geo_box[3], inps.geo_box[1],
-                    inps.geo_box[0], inps.geo_box[2])
             ax = pp.plot_gps(ax, SNWE, inps, metadata, print_msg=inps.print_msg)
 
         # Status bar
@@ -620,13 +650,18 @@ def plot_slice(ax, data, metadata, inps):
                 print_msg=inps.print_msg,
             )
 
-        # Plot Data
-        vprint('plotting Data ...')
         # extent = (left, right, bottom, top) in data coordinates
-        extent = (inps.pix_box[0]-0.5, inps.pix_box[2]-0.5,
-                  inps.pix_box[3]-0.5, inps.pix_box[1]-0.5)
-        im = ax.imshow(data, cmap=inps.colormap, vmin=inps.vlim[0], vmax=inps.vlim[1],
-                       extent=extent, interpolation=inps.interpolation, alpha=inps.transparency, zorder=1)
+        inps.extent = (inps.pix_box[0]-0.5, inps.pix_box[2]-0.5,
+                       inps.pix_box[3]-0.5, inps.pix_box[1]-0.5)
+
+        # Plot Data
+        if inps.disp_dem_blend:
+            im = pp.plot_blend_image(ax, data, dem, inps, print_msg=inps.print_msg)
+        else:
+            vprint('plotting data ...')
+            im = ax.imshow(data, cmap=inps.colormap, vmin=inps.vlim[0], vmax=inps.vlim[1],
+                           extent=inps.extent, interpolation=inps.interpolation,
+                           alpha=inps.transparency, zorder=1)
         ax.tick_params(labelsize=inps.font_size)
 
         # Plot Seed Point
@@ -661,8 +696,8 @@ def plot_slice(ax, data, metadata, inps):
             ])
             ax.plot(pts_yx[:, 1], pts_yx[:, 0], '-', ms=inps.ref_marker_size, mec='black', mew=1.)
 
-        ax.set_xlim(extent[0:2])
-        ax.set_ylim(extent[2:4])
+        ax.set_xlim(inps.extent[0:2])
+        ax.set_ylim(inps.extent[2:4])
 
         # Status bar
 
@@ -734,7 +769,7 @@ def plot_slice(ax, data, metadata, inps):
     if inps.disp_tick:
         # move x-axis tick label to the top if colorbar is at the bottom
         if inps.cbar_loc == 'bottom':
-            ax.tick_params(labelbottom=False, labeltop=True)
+            ax.tick_params(bottom=False, top=True, labelbottom=False, labeltop=True)
 
         # manually turn ON to enable tick labels for UTM with cartopy
         # link: https://github.com/SciTools/cartopy/issues/491
@@ -1117,7 +1152,9 @@ def read_data4figure(i_start, i_end, inps, metadata):
             or inps.key in ['timeseries', 'inversion']
             or all(d in inps.dsetFamilyList for d in ['horizontal', 'vertical'])
             or inps.dsetFamilyList == ['data','model','residual']
-            or inps.dsetFamilyList == [f'band{i+1}' for i in range(len(inps.dsetFamilyList))]):
+            or inps.dsetFamilyList == [f'band{i+1}' for i in range(len(inps.dsetFamilyList))]
+            or all(d.endswith('Amplitude') for d in inps.dsetFamilyList)
+            or all(d.endswith('Phase') for d in inps.dsetFamilyList)):
         same_unit4all_subplots = True
     else:
         same_unit4all_subplots = False
@@ -1174,14 +1211,12 @@ def plot_subplot4figure(i, inps, ax, data, metadata):
             print_msg=inps.print_msg)
 
     # Plot Data
-    vlim = inps.vlim
-    vlim = vlim if vlim is not None else [np.nanmin(data), np.nanmax(data)]
-    extent = (inps.pix_box[0]-0.5, inps.pix_box[2]-0.5,
-              inps.pix_box[3]-0.5, inps.pix_box[1]-0.5)
-
+    vlim = inps.vlim if inps.vlim is not None else [np.nanmin(data), np.nanmax(data)]
+    inps.extent = (inps.pix_box[0]-0.5, inps.pix_box[2]-0.5,
+                   inps.pix_box[3]-0.5, inps.pix_box[1]-0.5)
     im = ax.imshow(data, cmap=inps.colormap, vmin=vlim[0], vmax=vlim[1],
                    interpolation=inps.interpolation, alpha=inps.transparency,
-                   extent=extent, zorder=1)
+                   extent=inps.extent, zorder=1)
 
     # Plot Seed Point
     if inps.disp_ref_pixel:
@@ -1194,11 +1229,11 @@ def plot_subplot4figure(i, inps, ax, data, metadata):
         if ref_y and ref_x:
             ax.plot(ref_x, ref_y, inps.ref_marker, ms=inps.ref_marker_size)
 
-    ax.set_xlim(extent[0:2])
-    ax.set_ylim(extent[2:4])
+    ax.set_xlim(inps.extent[0:2])
+    ax.set_ylim(inps.extent[2:4])
 
-    # Subplot Setting
-    ## Tick and Label
+    ## Subplot Setting
+    # Tick and Label
     if not inps.disp_tick or inps.fig_row_num * inps.fig_col_num > 10:
         ax.get_xaxis().set_ticks([])
         ax.get_yaxis().set_ticks([])
@@ -1228,7 +1263,7 @@ def plot_subplot4figure(i, inps, ax, data, metadata):
             # ignore dataset family info if there is only one type
             if len(inps.dsetFamilyList) == 1 and '-' in title_str:
                 title_str = title_str.split('-')[1]
-                # for ifgramStack, show index in the date12 list to facilitate the network modfication
+                # for ifgramStack, show index in the date12 list to facilitate the network modification
                 if inps.atr['FILE_TYPE'] == 'ifgramStack':
                     title_ind = inps.date12List.index(title_str)
 
@@ -1366,11 +1401,11 @@ def plot_figure(j, inps, metadata):
             vprint('Note: different color scale for EACH subplot!')
             vprint('Adjust figsize for the colorbar of each subplot.')
             fig.set_size_inches(inps.fig_size[0] * 1.1, inps.fig_size[1])
-
             adjust_subplots_layout(fig, inps)
+
         else:
             adjust_subplots_layout(fig, inps)
-
+            # plot common colorbar
             cbar_length = 0.4
             if inps.fig_size[1] > 8.0:
                 cbar_length /= 2
@@ -1465,7 +1500,7 @@ def prepare4multi_subplots(inps, metadata):
                 print_msg=False,
             )[0]
 
-            inps.dem_shade, inps.dem_contour, inps.dem_contour_seq = pp.prepare_dem_background(
+            inps.dem_shade, inps.dem_contour, inps.dem_contour_seq = pp.prep_dem_background(
                 dem=dem,
                 inps=inps,
                 print_msg=inps.print_msg,
